OC.L10N.register(
    "core",
    {
    "Please select a file." : "Velg en fil.",
    "File is too big" : "Filen er for stor",
    "The selected file is not an image." : "Den valgte filen er ikke et bilde.",
    "The selected file cannot be read." : "Den valgte filen kan ikke leses.",
    "The file was uploaded" : "Filen ble lastet opp",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Filen er større enn definert grense i upload_max_filesize satt i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Filen er større enn definert grense i MAX_FILE_SIZE  satt i HTML-formen.",
    "The file was only partially uploaded" : "Filen ble kun delvis opplastet",
    "No file was uploaded" : "Ingen fil var lastet opp",
    "Missing a temporary folder" : "Mangler midlertidig mappe",
    "Could not write file to disk" : "Skriving til disk mislyktes",
    "A PHP extension stopped the file upload" : "En PHP-utvidelse stoppet filopplastingen.",
    "Invalid file provided" : "Ugyldig fil oppgitt",
    "No image or file provided" : "Ikke noe bilde eller fil angitt",
    "Unknown filetype" : "Ukjent filtype",
    "An error occurred. Please contact your admin." : "Det oppsto en feil. Kontakt din administrator.",
    "Invalid image" : "Ugyldig bilde",
    "State token does not match" : "Tilstandsnøkkel samsvarer ikke",
    "Invalid app password" : "Ugyldig programpassord",
    "Could not complete login" : "Kunne ikke fullføre pålogging",
    "State token missing" : "Tilstandsnøkkel mangler",
    "Your login token is invalid or has expired" : "Innloggingen din er ugyldig eller utgått",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Denne fellesskapsutgaven av Nextcloud støttes ikke og push-varslinger er begrenset.",
    "Login" : "Logg inn",
    "Unsupported email length (>255)" : "E-postlengde som ikke støttes (>255)",
    "Password reset is disabled" : "Tilbakestilling av passord er avskrudd",
    "Could not reset password because the token is expired" : "Kan ikke tilbakestille passordet fordi token er utgått.",
    "Could not reset password because the token is invalid" : "Kan ikke tilbakestille passordet fordi token er ugyldig.",
    "Password is too long. Maximum allowed length is 469 characters." : "Passordet er for langt. Maksimal tillatt lengde er 469 tegn.",
    "%s password reset" : "%s tilbakestilling av passord",
    "Password reset" : "Tilbakestilling av passord",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Klikk følgende knapp for å tilbakestille passordet ditt. Ignorer denne e-posten hvis du ikke har forespurt dette.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Klikk følgende lenke for å tilbakestille passordet ditt. Ignorer denne e-posten hvis du ikke har forespurt dette.",
    "Reset your password" : "Tilbakestill passordet ditt",
    "The given provider is not available" : "Den oppgitte leverandøren er ikke tilgjengelig",
    "Task not found" : "Oppgave ikke funnet",
    "Internal error" : "Intern feil",
    "Not found" : "Ikke funnet",
    "Bad request" : "Feilaktig forespørsel",
    "Requested task type does not exist" : "Den forespurte oppgavetypen eskisterer ikke",
    "Necessary language model provider is not available" : "Nødvendig tilbyder av språkmodell er ikke tilgjengelig",
    "No text to image provider is available" : "Ingen tilbyder av tekst til bilde er tilgjengelig",
    "Image not found" : "Bilde ikke funnet",
    "No translation provider available" : "Ingen tilbyder av oversetting er tilgjengelig",
    "Could not detect language" : "Kunne ikke gjenkjenne srpåk",
    "Unable to translate" : "Ikke i stand til å oversette",
    "No valid filters provided" : "Ingen gyldige filtre oppgitt.",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Reparasjonstrinn:",
    "Repair info:" : "Reparasjonsinformasjon:",
    "Repair warning:" : "Reparasjonsadvarsel:",
    "Repair error:" : "Reparasjonsfeil:",
    "Nextcloud Server" : "Nextcloud-server",
    "Some of your link shares have been removed" : "Noen av de delte lenkene dine har blitt fjernet",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "På grunn av et sikkerhetsproblem har vi fjernet enkelte av de delte lenkene dine. Vennligst se linken for mer informasjon. ",
    "The account limit of this instance is reached." : "Kontogrensen for denne forekomsten er nådd.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Skriv inn abonnementsnøkkelen din i støtteappen for å øke brukergrensen. Dette gir deg også alle tilleggsfordeler som Nextcloud Enterprise tilbyr og anbefales på det sterkeste for driften i selskaper.",
    "Learn more ↗" : "Lær mer ↗",
    "Preparing update" : "Forbereder oppdatering",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Vennligst bruk kommandolinje til å oppdatere.  Oppdatering via nettleser er ikke aktivert i din config.php.",
    "Turned on maintenance mode" : "Vedlikeholdmodus aktivt",
    "Turned off maintenance mode" : "Vedlikeholdmodus er deaktivert",
    "Maintenance mode is kept active" : "Vedlikeholdmodus beholdes aktivt",
    "Updating database schema" : "Oppdaterer database-skjemaet",
    "Updated database" : "Database er oppdatert",
    "Update app \"%s\" from App Store" : "Oppdater appen \"%s\" fra appbutikk",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Sjekker om databaseskjemaet for %s kan oppdateres (dette kan ta lang tid hvis databasen er stor)",
    "Updated \"%1$s\" to %2$s" : "Oppdaterte \"%1$s\" til %2$s",
    "Set log level to debug" : "Sett loggnivå for feilsøking",
    "Reset log level" : "Standard loggnivå",
    "Starting code integrity check" : "Starter sjekk av kode-integritet",
    "Finished code integrity check" : "Fullførte sjekk av kodeintegritet",
    "%s (incompatible)" : "%s (ikke kompatibel)",
    "The following apps have been disabled: %s" : "Følgende apper har blitt deaktivert: %s",
    "Already up to date" : "Allerede oppdatert",
    "JSON document" : "JSON-dokument",
    "Microsoft Word document" : "Microsoft Word-dokument",
    "Unknown" : "Ukjent",
    "PDF document" : "PDF-dokument",
    "PowerPoint presentation" : "PowerPoint-presentasjon",
    "Word document" : "Word-dokument",
    "ODG template" : "ODG-mal",
    "ODP presentation" : "ODP-presentasjon",
    "ODP template" : "ODP-mal",
    "ODS template" : "ODS-mal",
    "ODT document" : "ODT-dokument",
    "ODT template" : "ODT-mal",
    "WordPerfect document" : "WordPerfect-dokument",
    "FictionBook document" : "FictionBook-dokument",
    "Krita document" : "Krita-dokument",
    "Perl script" : "Perl-skript",
    "PHP script" : "PHP-skript",
    "Tar archive" : "Tar-arkiv",
    "XML document" : "XML-dokument",
    "YAML document" : "YAML-dokument",
    "Zip archive" : "Zip-arkiv",
    "Zstandard archive" : "Zstandard-arkiv",
    "EMF image" : "EMF-bilde",
    "GIF image" : "GIF-bilde",
    "HEIC image" : "HEIC-bilde",
    "HEIF image" : "HEIF-bilde",
    "JPEG image" : "JPEG-bilde",
    "PNG image" : "PNG-bilde",
    "SVG image" : "SVG-bilde",
    "TIFF image" : "TIFF-bilde",
    "WebP image" : "WebP-bilde",
    "Windows Icon" : "Windows-ikon",
    "Email message" : "Epostmelding",
    "CSV document" : "CSV-dokument",
    "HTML document" : "HTML-dokument",
    "Markdown document" : "Markdown-dokument",
    "C++ source code" : "C++-kildekode",
    "LDIF address book" : "LDIF-adressebok",
    "NFO document" : "NFO-dokument",
    "PHP source" : "PHP-kilde",
    "Python script" : "Python-skript",
    "ReStructuredText document" : "ReStructuredText-dokument",
    "MPEG video" : "MPEG-video",
    "DV video" : "DV-video",
    "MPEG-4 video" : "MPEG-4-video",
    "Ogg video" : "Ogg-video",
    "QuickTime video" : "QuickTime-video",
    "WebM video" : "WebM-video",
    "Flash video" : "Flash-video",
    "Matroska video" : "Mastroka-video",
    "Windows Media video" : "Windows Media-video",
    "AVI video" : "AVI-video",
    "The update is in progress, leaving this page might interrupt the process in some environments." : "En oppdatering foregår, lukking av denne siden kan forstyrre prosessen på enkelte systemer.",
    "Update to {version}" : "Oppdater til {version}",
    "An error occurred." : "En feil oppsto.",
    "Please reload the page." : "Last inn siden på nytt.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Oppdateringen var mislykket. For mer informasjon <a href=\"{url}\">se vår forum-artikkel</a> som beskriver dette problemet.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Oppdateringen mislyktes. Rapporter dette problemet til <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-gemenskapen</a>.",
    "Continue to {productName}" : "Fortsett til {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Oppdatering er vellykket. Går videre til {productName} om %n sekunder.","Oppdatering er vellykket. Går videre til {productName} om %n sekunder."],
    "Done" : "Ferdig",
    "Applications menu" : "Applikasjonsmeny",
    "Apps" : "Apper",
    "More apps" : "Flere apper",
    "_{count} notification_::_{count} notifications_" : ["{count} varsel","{count} varsler"],
    "No" : "Nei",
    "Yes" : "Ja",
    "App password" : "App passord",
    "Grant access" : "Gi tilgang",
    "The remote URL must include the user." : "Den eksterne URL-adressen må inkludere brukeren.",
    "Invalid remote URL." : "Ugyldig ekstern URL.",
    "Failed to add the public link to your Nextcloud" : "Feil oppsto under oppretting av offentlig lenke til din Nextcloud",
    "Federated user" : "Forent bruker",
    "user@your-nextcloud.org" : "bruker@din-nextcloud.org",
    "Create share" : "Opprett deling",
    "Direct link copied" : "Direktelenke kopiert",
    "Please copy the link manually:" : "Vennligst kopier lenken manuelt:",
    "Custom date range" : "Egendefinert datoperiode",
    "Pick start date" : "Velg start dato",
    "Pick end date" : "Velg sluttdato",
    "Search in date range" : "Søk innenfor valgte datoer",
    "Search in current app" : "Søk i gjeldende app",
    "Clear search" : "Tøm søk",
    "Search everywhere" : "Søk overalt",
    "Start typing to search" : "Start å skrive for å søke",
    "Minimum search length is {minSearchLength} characters" : "Minimum søklengde er {minSearchLength}tegn",
    "No matching results" : "Ingen treff",
    "Today" : "I dag",
    "Last 7 days" : "Siste 7 dager",
    "Last 30 days" : "Siste 30 dager",
    "This year" : "I år",
    "Last year" : "I fjor",
    "Between {startDate} and {endDate}" : "Mellom {startDate}og {endDate}",
    "Unified search" : "Enhetlig søk",
    "Search apps, files, tags, messages" : "Søk i apper, filer, tagger, meldinger",
    "Places" : "Steder",
    "Date" : "Dato",
    "Search people" : "Søk etter personer",
    "People" : "Mennesker",
    "Filter in current view" : "Filter i gjeldende visning",
    "Search connected services" : "Søk etter tilkoblede tjenester",
    "Results" : "Resultater",
    "Load more results" : "Last flere resultater",
    "Search in" : "Søk i",
    "Log in" : "Logg inn",
    "Log in to {productName}" : "Logg på {productName}",
    "Wrong login or password." : "Feil pålogging eller passord.",
    "This account is disabled" : "Denne kontoen er deaktivert",
    "Account name or email" : "Kontonavn eller e-postadresse",
    "Account name" : "Kontonavn",
    "Server side authentication failed!" : "Autentisering mislyktes på serveren!",
    "Please contact your administrator." : "Kontakt administratoren din.",
    "Session error" : "Sesjonfeil",
    "An internal error occurred." : "En intern feil oppsto",
    "Please try again or contact your administrator." : "Prøv igjen eller kontakt en administrator.",
    "Password" : "Passord",
    "Log in with a device" : "Logg inn med en enhet",
    "Login or email" : "Pålogging eller e-post",
    "Your account is not setup for passwordless login." : "Kontoen din er ikke satt opp med passordløs innlogging.",
    "Your connection is not secure" : "Tilkoblingen din er ikke sikker",
    "Passwordless authentication is only available over a secure connection." : "Passordløs innlogging støttes kun over en sikker tilkobling.",
    "Browser not supported" : "Nettleseren din støttes ikke!",
    "Passwordless authentication is not supported in your browser." : "Passordløs innlogging støttes ikke av nettleseren din.",
    "Reset password" : "Tilbakestill passord",
    "Back to login" : "Tilbake til innlogging",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Hvis denne kontoen finnes, er det sendt en melding om tilbakestilling av passord til e-postadressen. Hvis du ikke mottar den, bekreft e-postadressen din og / eller logg inn, sjekk spam / søppelpostmappene dine eller spør din lokale administrasjon om hjelp.",
    "Couldn't send reset email. Please contact your administrator." : "Klarte ikke å sende e-post for tilbakestilling. Kontakt administratoren.",
    "Password cannot be changed. Please contact your administrator." : "Passordet kan ikke endres. Kontakt administratoren din.",
    "New password" : "Nytt passord",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Dine filer er kryptert. Det finnes ingen måte å få dine data tilbake etter at passordet er nullstilt. Hvis du er usikker på hva du skal gjøre, vennligst kontakt din administrator før du fortsetter. Er du helt sikker på at du vil fortsette?",
    "I know what I'm doing" : "Jeg vet hva jeg gjør",
    "Resetting password" : "Tilbakestill passord",
    "Schedule work & meetings, synced with all your devices." : "Planlegg jobb og møter, synkronisert med alle dine enheter.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Ha dine kollegaer og venner på en plass uten å lekke deres private info.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Enkel e-post app smidig integrert med Filer, Kontakter og Kalender.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, videosamtaler, skjermdeling, nettmøter og webkonferanser – i din nettleser og med mobilapper.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Samarbeidsdokumenter, regneark og presentasjoner, bygget på Collabora Online.",
    "Distraction free note taking app." : "Distraksjonsfri notatapp.",
    "Recommended apps" : "Anbefalte apper",
    "Could not fetch list of apps from the App Store." : "Kunne ikke hente liste med apper fra appbutikken. ",
    "App download or installation failed" : "Nedlasting eller installasjon av app feilet ",
    "Cannot install this app because it is not compatible" : "Kan ikke installere denne appen fordi den ikke er kompatibel",
    "Cannot install this app" : "Kan ikke installere denne appen",
    "Skip" : "Hopp over",
    "Install recommended apps" : "Installer anbefalte apper",
    "Online" : "Pålogget",
    "Away" : "Borte",
    "Busy" : "Opptatt",
    "Do not disturb" : "Ikke forstyrr",
    "Mute all notifications" : "Demp alle varslinger",
    "Invisible" : "Usynlig",
    "Appear offline" : "Vis som frakoblet",
    "Avatar of {displayName}" : "{displayName} sin Avatar",
    "Settings menu" : "Meny for innstillinger",
    "Search contacts" : "Søk etter kontakter",
    "Reset search" : "Tilbakestill søk",
    "Could not load your contacts" : "Kunne ikke laste inn kontaktene dine",
    "No contacts found" : "Fant ingen kontakter",
    "Show all contacts" : "Vis alle kontakter",
    "Install the Contacts app" : "Installer appen Kontakter",
    "Search" : "Søk",
    "No results for {query}" : "Ingen resultater for {query}",
    "Press Enter to start searching" : "Trykk Enter for å starte søk",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Skriv minst {minSearchLength} bokstav for å søke","Skriv minst {minSearchLength} bokstaver for å søke"],
    "An error occurred while searching for {type}" : "Det oppsto en feil ved søk etter {type}",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Søket starter når du begynner å skrive, og resultater kan nås med piltastene",
    "Search for {name} only" : "Søk kun etter {name}",
    "Forgot password?" : "Glemt passord?",
    "Back to login form" : "Tilbake til innloggingsskjema",
    "Back" : "Tilbake",
    "Login form is disabled." : "Innloggingskjemaet er deaktivert.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud-påloggingsskjemaet er deaktivert. Bruk et annet påloggingsalternativ hvis tilgjengelig, eller kontakt administrasjonen din.",
    "Connect to your account" : "Koble til kontoen din",
    "Security warning" : "Sikkerhetsadvarsel",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Hvis du ikke prøver å sette opp en ny enhet eller app, så er det noen som nå prøver å lure deg til å gi de tilgang til dine data. Stopp i så fall øyeblikkelig og kontakt din systemadministrator.",
    "Alternative log in using app password" : "Alternativ innlogging ved bruk av app passord",
    "Account connected" : "Konto er koblet",
    "Your client should now be connected!" : "Din klient skal nå være koblet til!",
    "You can close this window." : "Du kan lukke dette vinduet.",
    "Account access" : "Kontotilgang",
    "More actions" : "Flere handlinger",
    "User menu" : "Brukermeny",
    "Your guest name: {user}" : "Ditt gjestenavn: {user}",
    "You are currently not identified." : "Du er for øyeblikket ikke identifisert.",
    "Set public name" : "Sett offentlig navn",
    "Change public name" : "Endre offentlig navn",
    "This share is password-protected" : "Denne deling er beskyttet med passord",
    "The password is wrong or expired. Please try again or request a new one." : "Passordet er feil eller har utgått. Prøv igjen eller be om et nytt.",
    "Submit" : "Send inn",
    "Please type in your email address to request a temporary password" : "Oppgi e-post adresse for å få midlertidig passord",
    "Password sent!" : "Passord er sendt.",
    "You are not authorized to request a password for this share" : "Du mangler tillatelse for å etterspørre passord til deling. ",
    "Email address" : "E-post adresse",
    "Request password" : "Forespør om passord",
    "Forgot password" : "Glemt passord",
    "Password is too weak" : "Passordet er for svakt",
    "Password is weak" : "Passordet er svakt",
    "Password is average" : "Passordet er middels sterkt",
    "Password is strong" : "Passordet er sterkt",
    "Password is very strong" : "Passordet er veldig sterkt",
    "Password is extremely strong" : "Passordet er ekstremt sterkt",
    "Unknown password strength" : "Ukjent passordstyrke",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Datamappen og filene dine er sannsynligvis tilgjengelig fra Internett fordi <code>.htaccess</code>-filen ikke fungerer.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "For informasjon om hvordan å konfigurere din server, vennligst {linkStart}se dokumentasjonen{linkEnd}",
    "Create administration account" : "Opprett administratorkonto",
    "Storage & database" : "Lagring og database",
    "Data folder" : "Datamappe",
    "Database configuration" : "Databasekonfigurasjon",
    "Only {firstAndOnlyDatabase} is available." : "Kun {firstAndOnlyDatabase} er tilgjengelig. ",
    "Install and activate additional PHP modules to choose other database types." : "Installer og aktiver flere PHP-moduler for å velge andre databasetyper.",
    "For more details check out the documentation." : "Henvend deg til dokumentasjonen for flere detaljer.",
    "Performance warning" : "Ytelsesadvarsel",
    "You chose SQLite as database." : "Du velger å bruke SQLite som database.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite skal bare bli brukt for minimale- eller utvikler-installasjoner. I vanlig bruk anbefaler vi å bruke et annet bakstykke.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Hvis du bruker klienter for filsynkronisering så er bruk av SQLite absolutt ikke anbefalt.",
    "Database user" : "Databasebruker",
    "Database password" : "Databasepassord",
    "Database name" : "Databasenavn",
    "Database tablespace" : "Database-tabellområde",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Spesifiser portnr. sammen med servernavnet (f.eks., localhost:5432).",
    "Database host" : "Databasevert",
    "Install" : "Installer",
    "Need help?" : "Trenger du hjelp?",
    "See the documentation" : "Se dokumentasjonen",
    "{name} version {version} and above" : "{name} versjon {version} og nyere",
    "This browser is not supported" : "Denne nettleseren støttes ikke",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Nettleseren din støttes ikke. Vennligst oppgrader til en nyere versjon eller en støttet versjon.",
    "Continue with this unsupported browser" : "Fortsett med denne nettleseren som ikke støttes",
    "Supported versions" : "Støttede versjoner",
    "Choose {file}" : "Velg {file}",
    "Choose" : "Velg",
    "Copy to {target}" : "Kopier til {target}",
    "Copy" : "Kopier",
    "Move to {target}" : "Flytt til {target}",
    "Move" : "Flytt",
    "OK" : "OK",
    "read-only" : "skrivebeskyttet",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} filkonflikt","{count} fil konflikter"],
    "One file conflict" : "En filkonflikt",
    "New Files" : "Nye filer",
    "Already existing files" : "Allerede eksisterende filer",
    "Which files do you want to keep?" : "Hvilke filer vil du beholde?",
    "If you select both versions, the copied file will have a number added to its name." : "Hvis du velger begge versjonene vil den kopierte filen få et nummer lagt til i navnet.",
    "Cancel" : "Avbryt",
    "Continue" : "Fortsett",
    "(all selected)" : "(alle valgt)",
    "({count} selected)" : "({count} valgt)",
    "Error loading file exists template" : "Feil ved lasting av \"filen eksisterer\"-mal",
    "Saving …" : "Lagrer ...",
    "Groups" : "Grupper",
    "Group list is empty" : "Gruppeliste er tom",
    "Unable to retrieve the group list" : "Kunne ikke hente gruppelisten",
    "seconds ago" : "for få sekunder siden",
    "Connection to server lost" : "Mistet tilkobling til server",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem ved lasting av side, laster på nytt om %n sekund","Problem ved lasting av side, laster på nytt om %n sekunder"],
    "Add to a project" : "Legg til i et prosjekt",
    "Show details" : "Vis detaljer",
    "Hide details" : "Skjul detaljer",
    "Rename project" : "Endre navn på prosjekt",
    "Failed to rename the project" : "Klarte ikke å endre navnet på prosjektet",
    "Failed to create a project" : "Klarte ikke å opprettet prosjektet",
    "Failed to add the item to the project" : "Klarte ikke å koble objektet til prosjektet",
    "Connect items to a project to make them easier to find" : "Koble objekter til et prosjekt gjør dem enklere å finne",
    "Type to search for existing projects" : "Skriv for å søke etter eksisterende prosjekter",
    "New in" : "Ny i",
    "View changelog" : "Se endringslogg",
    "Close \"{dialogTitle}\" dialog" : "Lukk \"{dialogTitle}\" dialogen",
    "Email length is at max (255)" : "E-postlengden er på maks (255)",
    "Clipboard not available, please copy manually" : "Utklippstavlen ikke tilgjengelig, kopier manuelt",
    "Personal" : "Personlig",
    "Accounts" : "Kontoer",
    "Admin" : "Admin",
    "Help" : "Hjelp",
    "Access forbidden" : "Tilgang nektet",
    "You are not allowed to access this page." : "Du har ikke tilgang til denne siden.",
    "Back to %s" : "Tilbake til %s",
    "Page not found" : "Siden ble ikke funnet",
    "The page could not be found on the server or you may not be allowed to view it." : "Siden ble ikke funnet på serveren, eller du har ikke tilgang til den.",
    "Too many requests" : "For mange forespørsler",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Det var for mange forespørsler fra ditt nettverk. Prøv igjen senere eller kontakt din administrator hvis dette er en feil.",
    "Error" : "Feil",
    "Internal Server Error" : "Intern serverfeil",
    "The server was unable to complete your request." : "Serveren kunne ikke fullføre din forespørsel.",
    "If this happens again, please send the technical details below to the server administrator." : "Hvis dette skjer igjen, send de tekniske detaljene nedenfor til serveradministratoren.",
    "More details can be found in the server log." : "Flere detaljer finnes i serverloggen.",
    "For more details see the documentation ↗." : "For mer detaljer se dokumentasjonen ↗.",
    "Technical details" : "Tekniske detaljer",
    "Remote Address: %s" : "Ekstern adresse: %s",
    "Request ID: %s" : "Forespørsels-ID: %s",
    "Type: %s" : "Type: %s",
    "Code: %s" : "Kode: %s",
    "Message: %s" : "Melding: %s",
    "File: %s" : "Fil: %s",
    "Line: %s" : "Linje: %s",
    "Trace" : "Sporing",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Det ser ut som at du forsøker å re installere Nextcloud. Filen CAN_INSTALL mangler imidlertid fra innstillingsmappen. Opprett filen CAN_INSTALL i innstillingsmappen for å fortsette.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Kunne ikke fjerne CAN_INSTALL fra konfigurasjonsmappa. Vennligst fjern denne filen manuelt.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Denne appen krever JavaScript for å fungere korrekt. {linkstart}Aktiver JavaScript{linkend} og last siden på nytt.",
    "Skip to main content" : "Gå til hovedinnhold",
    "Skip to navigation of app" : "Gå til navigasjon av app",
    "Go to %s" : "Gå til %s",
    "Get your own free account" : "Få din egen gratis konto",
    "Previous" : "Forrige",
    "Two-factor authentication" : "Tofaktor-autentisering",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Utvidet sikkerhet er tilgjengelig fo rdin konto. Velg en to-faktor for autentisering.",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Kunne ikke laste minst en av de aktiverte tofaktor metodene. Ta kontakt med administrasjonen din.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "To-faktor autentisering er aktivert men er ikke satt opp for din konto. Kontakt administrator for hjelp.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Tofaktor autentisering er påkrevd, men er ikke satt opp for din konto. Vennligst gå videre for å sette opp tofaktor autentisering.",
    "Set up two-factor authentication" : "Opprett totrinns bekreftelse",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "To-faktor autentisering er aktivert men er ikke satt opp for din konto. Bruk en av dine sikkerhet koder for å logge inn eller kontakt administrator for hjelp.",
    "Use backup code" : "Bruker sikkerhetskopi kode",
    "Cancel login" : "Avbryt innlogging",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Utvidet sikkerhet håndheves for din konto. Velg hvilken tilbyder som skal brukes:",
    "Error while validating your second factor" : "Feil under validering av din andre faktor",
    "Access through untrusted domain" : "Nå gjennom ubetrodd domene",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Kontakt din administrator. Hvis du er en administrator, sett opp innstillingen \"trusted_domains\" i config/config.php som eksemplet i config/config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Ytterligere informasojn om oppsett finnes i %1$sdokumentasjon%2$s.",
    "App update required" : "Oppdatering av app kreves",
    "%1$s will be updated to version %2$s" : "%1$soppdateres til versjon %2$s",
    "The following apps will be updated:" : "Følgende apper vil bli oppdatert:",
    "These incompatible apps will be disabled:" : "Disse ikke-kompatible appene vil bli deaktivert:",
    "The theme %s has been disabled." : "Temaet %s har blitt deaktivert.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Forsikre deg om at databasen, config-mappen og datamappen er blitt sikkerhetskopiert før du fortsetter.",
    "Start update" : "Start oppdatering",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "For å unngå tidsavbrudd ved store installasjoner, kan du i stedet kjøre følgende kommando fra installasjonsmappen:",
    "Detailed logs" : "Detaljerte logger",
    "Update needed" : "Oppdatering er nødvendig",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Bruk kommandolinjeoppdatereren siden du har en stor forekomst med mer enn 50 kontoer.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "For hjelp, les <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentasjonen</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Jeg vet at hvis jeg fortsetter oppdateringen via web-grensesnittet er det en mulighet for tap av data som følge av tidsavbrudd, men jeg har en sikkerhetskopi og vet hvordan jeg skal gjenopprette min installasjon hvis den feiler.",
    "Upgrade via web on my own risk" : "Oppgrader via web på min egen risikio",
    "Maintenance mode" : "Modus for vedlikehold",
    "This %s instance is currently in maintenance mode, which may take a while." : "Denne %s-instansen er for øyeblikket i vedlikeholdsmodus, noe som kan vare en stund.",
    "This page will refresh itself when the instance is available again." : "Siden vil oppdatere seg selv når instans er tilgjengelig igjen.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontakt systemadministratoren hvis denne meldingen var uventet eller ikke forsvinner.",
    "Error occurred while checking server setup" : "Feil oppsto ved sjekking av server-oppsett",
    "For more details see the {linkstart}documentation ↗{linkend}." : "For mer informasjon se {linkstart}dokumentasjonen ↗{linkend}.",
    "unknown text" : "ukjent tekst",
    "Hello world!" : "Hei, verden!",
    "sunny" : "solfylt",
    "Hello {name}, the weather is {weather}" : "Hallo {name}, været er {weather}",
    "Hello {name}" : "Hallo {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dette er dine søketreff<script>alert(1)</script></strong>",
    "new" : "ny",
    "_download %n file_::_download %n files_" : ["last ned %n fil","last ned %n filer"],
    "Direct link copied to clipboard" : "Direkte lenke kopiert til utklippstavlen",
    "Searching …" : "Søker ...",
    "Logging in …" : "Logger inn…",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Vi har detektert flere ugyldige påloggingsforsøk fra din IP-adresse. Derfor er din neste innlogging forsinket med opptil 30 sekunder.",
    "Loading apps …" : "Laster apper ... ",
    "Installing apps …" : "Installerer apper ... ",
    "Loading your contacts …" : "Laster inn kontaktene dine…",
    "Looking for {term} …" : "Ser etter {term}…",
    "Search contacts …" : "Søk etter kontakter…",
    "Loading more results …" : "Laster flere resultater ...",
    "Search {types} …" : "Søk {types} ...",
    "Saving …" : "Lagrer...",
    "Very weak password" : "Veldig svakt passord",
    "Weak password" : "Svakt passord",
    "So-so password" : "Bob-bob-passord",
    "Good password" : "Bra passord",
    "Strong password" : "Sterkt passord",
    "No action available" : "Ingen handling tilgjengelig",
    "Error fetching contact actions" : "Feil ved innhenting av kontakt-handlinger",
    "Non-existing tag #{tag}" : "Ikke-eksisterende merkelapp #{tag}",
    "Restricted" : "Begrenset",
    "Delete" : "Slett",
    "Rename" : "Gi nytt navn",
    "Collaborative tags" : "Samarbeidsmerkelapper",
    "No tags found" : "Ingen emneknagger funnet",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Datamappen og filene dine er sannsynligvis tilgjengelig fra Internett fordi .htaccess-filen ikke fungerer.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For informasjon om hvordan du skal konfigurere serveren skikkelig, les <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentasjonen</a>.",
    "<strong>Create an admin account</strong>" : "<strong>Opprett en administratorkonto</strong>",
    "New admin account name" : "Navn på ny administratorkonto",
    "New admin password" : "Passord for ny administratorkonto",
    "Show password" : "Vis passord",
    "Toggle password visibility" : "Vis passord av/på",
    "Configure the database" : "Sett opp databasen",
    "Only %s is available." : "Kun %s er tilgjengelig.",
    "Database account" : "Databasekonto",
    "Installing …" : "Installerer ...",
    "Please log in before granting %1$s access to your %2$s account." : "Logg inn før du tildeler %1$stilgang til din %2$skonto.",
    "Currently logged in as %1$s (%2$s)." : "Logget inn som %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Du er i ferd med å tildele %1$s tilgang til din %2$skonto."
},
"nplurals=2; plural=(n != 1);");
